black_76_price

Function black_76_price 

pub fn black_76_price(
    option_type: &OptionType,
    forward: f64,
    strike: f64,
    time_to_expiry: f64,
    risk_free_rate: f64,
    volatility: f64,
) -> f64
Price a European option on a futures contract under Black-76.

At or past expiry (time_to_expiry <= 0) the price is just intrinsic value. There is nothing left to discount, and the e^(-r * tau) factor would be greater than 1 for negative tau, inflating expired options above intrinsic.